@@ -1,5 +1,3 @@
-package org.apache.maven.plugins.source;
-
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
@@ -18,6 +16,7 @@ package org.apache.maven.plugins.source;
  * specific language governing permissions and limitations
  * under the License.
  */
+package org.apache.maven.plugins.source;
 
 import org.apache.maven.plugins.annotations.Execute;
 import org.apache.maven.plugins.annotations.LifecyclePhase;
@@ -28,10 +27,8 @@ import org.apache.maven.plugins.annotations.Mojo;
  *
  * @since 2.0.3
  */
-@Mojo( name = "test-jar", defaultPhase = LifecyclePhase.PACKAGE, threadSafe = true )
-@Execute( phase = LifecyclePhase.GENERATE_SOURCES )
-public class TestSourceJarMojo
-    extends TestSourceJarNoForkMojo
-{
+@Mojo(name = "test-jar", defaultPhase = LifecyclePhase.PACKAGE, threadSafe = true)
+@Execute(phase = LifecyclePhase.GENERATE_SOURCES)
+public class TestSourceJarMojo extends TestSourceJarNoForkMojo {
     // no op
 }
